==> swibots-1.4.20b0-py3-none-any.whl: swibots/api/callback/BottomBar.py <==
from enum import Enum
from swibots.base import SwitchObject
from swibots.utils.types import JSONDict
from typing import Dict, Any, List


class BottomBarTile(SwitchObject):
    def __init__(
        self,
        name: str,
        icon: str = "",
        selection_icon: str = "",
        dark_icon: str = "",
        dark_selection_icon: str = "",
        callback_data: str = "",
        selected: bool = False,
    ):
        self.name = name
        self.icon = icon
        self.selected_icon = selection_icon
        self.dark_icon = dark_icon or icon
        self.dark_selection_icon = dark_selection_icon or selection_icon
        self.selected = selected
        self.callback_data = callback_data

    def to_json(self):
        return {
            "name": self.name,
            "icon": self.icon,
            "selectionIcon": self.selected_icon,
            "selected": self.selected,
            "callbackData": self.callback_data,
            "darkIcon": self.dark_icon,
            "darkSelectedIcon": self.dark_selection_icon
        }


class BottomBarType(Enum):
    DEFAULT = "default"
    TOPLINE = "topline"
    BOTTOMLINE = "bottomline"
    TOP_NOTCH = "top_notch"
    BOTTOM_NOTCH = "bottom_notch"


class BottomBar(SwitchObject):
    def __init__(
        self,
        options: List[BottomBarTile],
        type: BottomBarType = BottomBarType.DEFAULT,
        theme_color: str = "",
    ):
        self.options = options
        self.type = type
        self.theme_color = theme_color

    def to_json(self):
        data = {
            "bottomBar": [option.to_json() for option in self.options],
            "bottomBarStyle": self.type.value,
        }
        if self.theme_color:
            data["bottomBarColour"] = self.theme_color
        return data

==> swibots-1.4.45-py3-none-any.whl: swibots/api/callback/BottomBar.py <==
from enum import Enum
from swibots.base import SwitchObject
from swibots.utils.types import JSONDict
from typing import Dict, Any, List


class BottomBarTile(SwitchObject):
    def __init__(
        self,
        name: str,
        icon: str = "",
        selection_icon: str = "",
        dark_icon: str = "",
        dark_selection_icon: str = "",
        callback_data: str = "",
        selected: bool = False,
    ):
        self.name = name
        self.icon = icon
        self.selected_icon = selection_icon
        self.dark_icon = dark_icon or icon
        self.dark_selection_icon = dark_selection_icon or selection_icon
        self.selected = selected
        self.callback_data = callback_data

    def to_json(self):
        return {
            "name": self.name,
            "icon": self.icon,
            "selectionIcon": self.selected_icon,
            "selected": self.selected,
            "callbackData": self.callback_data,
            "darkIcon": self.dark_icon,
            "darkSelectedIcon": self.dark_selection_icon,
        }


class BottomBarType(Enum):
    DEFAULT = "default"
    TOPLINE = "topline"
    BOTTOMLINE = "bottomline"
    TOP_NOTCH = "top_notch"
    BOTTOM_NOTCH = "bottom_notch"


class BottomBar(SwitchObject):
    def __init__(
        self,
        options: List[BottomBarTile],
        type: BottomBarType = BottomBarType.DEFAULT,
        theme_color: str = "",
    ):
        self.options = options
        self.type = type
        self.theme_color = theme_color

    def to_json(self):
        data = {
            "bottomBar": [option.to_json() for option in self.options],
            "bottomBarStyle": self.type.value,
        }
        if self.theme_color:
            data["bottomBarColour"] = self.theme_color
        return data
